gaussdecomp package
===================

Submodules
----------

gaussdecomp.cube module
-----------------------

.. automodule:: gaussdecomp.cube
   :members:
   :undoc-members:
   :show-inheritance:

gaussdecomp.driver module
-------------------------

.. automodule:: gaussdecomp.driver
   :members:
   :undoc-members:
   :show-inheritance:

gaussdecomp.fitter module
-------------------------

.. automodule:: gaussdecomp.fitter
   :members:
   :undoc-members:
   :show-inheritance:

gaussdecomp.spectrum module
---------------------------

.. automodule:: gaussdecomp.spectrum
   :members:
   :undoc-members:
   :show-inheritance:

gaussdecomp.utils module
------------------------

.. automodule:: gaussdecomp.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: gaussdecomp
   :members:
   :undoc-members:
   :show-inheritance:
